@@ -12,7 +12,7 @@ from django.db import router, transaction
 from django.db.models import Count
 from django.http import HttpResponseRedirect, JsonResponse
 from django.shortcuts import get_object_or_404
-from django.urls import reverse
+from django.urls import re_path, reverse
 from django.utils.functional import cached_property
 from django.utils.text import capfirst
 from django.utils.translation import gettext_lazy as _
@@ -21,12 +21,6 @@ from tree_queries.forms import TreeNodeChoiceField
 from cabinet.models import Folder
 
 
-try:
-    from django.urls import re_path
-except ImportError:
-    from django.conf.urls import url as re_path
-
-
 class FolderListFilter(admin.RelatedFieldListFilter):
     """
     Filters are hidden in the file changelist; this filter is only responsible
@@ -279,7 +273,7 @@ class FolderAdminMixin(admin.ModelAdmin):
         if folder_id:
             querydict.append(("folder__id__exact", folder_id))
         return HttpResponseRedirect(
-            "%s%s%s" % (url, "?" if querydict else "", urlencode(sorted(querydict)))
+            "{}{}{}".format(url, "?" if querydict else "", urlencode(sorted(querydict)))
         )
 
     def move_to_folder(self, request, queryset):
@@ -428,9 +422,7 @@ class FileAdminBase(FolderAdminMixin):
             kw = {}
             if request.COOKIES.get("cabinet_folder"):
                 kw["folder__id__exact"] = request.COOKIES["cabinet_folder"]
-            return HttpResponseRedirect(
-                "?{}".format(cabinet_querystring(request, **kw))
-            )
+            return HttpResponseRedirect(f"?{cabinet_querystring(request, **kw)}")
 
         cabinet_context = {
             # Keep query params except those in the set below when changing
